Learn R Programming

LMERConvenienceFunctions (version 3.2)

cd: Change directory.

Description

Change directory to the one corresponding to the row number listed by function f.

Usage

cd(dir)

Value

Change directory to the selected one.

Arguments

dir

The row number corresponding to the directory list returned by function f.

Author

Antoine Tremblay, Statistics Canada, trea26@gmail.com

See Also

f; cdf; cdup; setwd