powered by
f
Change directory to the one corresponding to the row number returned by function f.
cdf(dir)
Cheange to new directory and list files and directories in new directory using function f.
The row number corresponding to the directory listed by function f.
Antoine Tremblay, Statistics Canada, trea26@gmail.com
f; cd; cdup; setwd
f;
cd;
cdup;
setwd