Learn R Programming

LMERConvenienceFunctions (version 3.2)

cn: List the column names of a data frame in matrix format.

Description

The colum names of the specified data frame are listed in matrix format, that is, each one appears in one row preceded by the row number.

Usage

cn(data.frame)

Value

A matrix containing the column names of the data frame.

Arguments

data.frame

A data frame.

Author

Antoine Tremblay, Statistics Canada, trea26@gmail.com

See Also