powered by
The colum names of the specified data frame are listed in matrix format, that is, each one appears in one row preceded by the row number.
cn(data.frame)
A matrix containing the column names of the data frame.
A data frame.
Antoine Tremblay, Statistics Canada, trea26@gmail.com
colnames